@@ -1,9 +1,9 @@
-#' @title Expression and dataframe for one-way ANOVA
-#' @name expr_oneway_anova
+#' @title One-way analysis of variance (ANOVA)
+#' @name oneway_anova
 #'
 #' @description
 #'
-#' \Sexpr[results=rd, stage=render]{rlang:::lifecycle("maturing")}
+#' \Sexpr[results=rd, stage=render]{rlang:::lifecycle("stable")}
 #'
 #' A dataframe containing results for one-way ANOVA.
 #'
@@ -28,9 +28,6 @@
 #' @param effsize.type Type of effect size needed for *parametric* tests. The
 #'   argument can be `"eta"` (partial eta-squared) or `"omega"` (partial
 #'   omega-squared).
-#' @param output If `"expression"`, will return expression with statistical
-#'   details, while `"dataframe"` will return a dataframe containing the
-#'   results.
 #' @param tr Trim level for the mean when carrying out `robust` tests. In case
 #'   of an error, try reducing the value of `tr`, which is by default set to
 #'   `0.2`. Lowering the value might help.
@@ -38,7 +35,7 @@
 #'   for the effect size (Default: `100`).
 #' @param bf.prior A number between `0.5` and `2` (default `0.707`), the prior
 #'   width to use in calculating Bayes factors and posterior estimates.
-#' @inheritParams expr_t_twosample
+#' @inheritParams two_sample_test
 #' @inheritParams expr_template
 #' @inheritParams bf_extractor
 #' @param ... Additional arguments (currently ignored).
@@ -56,7 +53,6 @@
 #' @importFrom dplyr select rename matches
 #' @importFrom rlang !! !!! quo_is_null eval_tidy expr enexpr ensym exec new_formula
 #' @importFrom stats oneway.test
-#' @importFrom afex aov_ez
 #' @importFrom WRS2 t1way rmanova wmcpAKP
 #' @importFrom stats friedman.test kruskal.test na.omit
 #' @importFrom effectsize rank_epsilon_squared kendalls_w
@@ -71,30 +67,32 @@
 #' # for reproducibility
 #' set.seed(123)
 #' library(statsExpressions)
+#' options(tibble.width = Inf, pillar.bold = TRUE, pillar.neg = TRUE)
 #'
 #' # ----------------------- parametric -------------------------------------
 #'
 #' # between-subjects
-#' expr_oneway_anova(
+#' oneway_anova(
 #'   data = ggplot2::msleep,
 #'   x = vore,
 #'   y = sleep_rem
 #' )
 #'
-#' # within-subjects design
-#' expr_oneway_anova(
-#'   data = iris_long,
-#'   x = condition,
-#'   y = value,
-#'   subject.id = id,
-#'   paired = TRUE,
-#'   output = "dataframe"
-#' )
+#' if (require("afex", quietly = TRUE)) {
+#'   # within-subjects design
+#'   oneway_anova(
+#'     data = iris_long,
+#'     x = condition,
+#'     y = value,
+#'     subject.id = id,
+#'     paired = TRUE
+#'   )
+#' }
 #'
 #' # ----------------------- non-parametric ----------------------------------
 #'
 #' # between-subjects
-#' expr_oneway_anova(
+#' oneway_anova(
 #'   data = ggplot2::msleep,
 #'   x = vore,
 #'   y = sleep_rem,
@@ -102,20 +100,19 @@
 #' )
 #'
 #' # within-subjects design
-#' expr_oneway_anova(
+#' oneway_anova(
 #'   data = iris_long,
 #'   x = condition,
 #'   y = value,
 #'   subject.id = id,
 #'   paired = TRUE,
-#'   type = "np",
-#'   output = "dataframe"
+#'   type = "np"
 #' )
 #'
 #' # ----------------------- robust -------------------------------------
 #'
 #' # between-subjects
-#' expr_oneway_anova(
+#' oneway_anova(
 #'   data = ggplot2::msleep,
 #'   x = vore,
 #'   y = sleep_rem,
@@ -123,20 +120,19 @@
 #' )
 #'
 #' # within-subjects design
-#' expr_oneway_anova(
+#' oneway_anova(
 #'   data = iris_long,
 #'   x = condition,
 #'   y = value,
 #'   subject.id = id,
 #'   paired = TRUE,
-#'   type = "r",
-#'   output = "dataframe"
+#'   type = "r"
 #' )
 #'
 #' # ----------------------- Bayesian -------------------------------------
 #'
 #' # between-subjects
-#' expr_oneway_anova(
+#' oneway_anova(
 #'   data = ggplot2::msleep,
 #'   x = vore,
 #'   y = sleep_rem,
@@ -146,36 +142,34 @@
 #' # within-subjects design
 #' # needs `BayesFactor 0.9.12-4.3` or above
 #' if (utils::packageVersion("BayesFactor") >= package_version("0.9.12-4.3")) {
-#'   expr_oneway_anova(
+#'   oneway_anova(
 #'     data = iris_long,
 #'     x = condition,
 #'     y = value,
 #'     subject.id = id,
 #'     paired = TRUE,
-#'     type = "bayes",
-#'     output = "dataframe"
+#'     type = "bayes"
 #'   )
 #' }
 #' }
 #' @export
 
 # function body
-expr_oneway_anova <- function(data,
-                              x,
-                              y,
-                              subject.id = NULL,
-                              type = "parametric",
-                              paired = FALSE,
-                              k = 2L,
-                              conf.level = 0.95,
-                              effsize.type = "omega",
-                              var.equal = FALSE,
-                              bf.prior = 0.707,
-                              tr = 0.2,
-                              nboot = 100,
-                              top.text = NULL,
-                              output = "expression",
-                              ...) {
+oneway_anova <- function(data,
+                         x,
+                         y,
+                         subject.id = NULL,
+                         type = "parametric",
+                         paired = FALSE,
+                         k = 2L,
+                         conf.level = 0.95,
+                         effsize.type = "omega",
+                         var.equal = FALSE,
+                         bf.prior = 0.707,
+                         tr = 0.2,
+                         nboot = 100,
+                         top.text = NULL,
+                         ...) {
 
   # standardize the type of statistics
   type <- ipmisc::stats_type_switch(type)
@@ -201,8 +195,11 @@ expr_oneway_anova <- function(data,
     if (effsize.type %in% c("unbiased", "omega")) .f.es <- effectsize::omega_squared
     if (effsize.type %in% c("biased", "eta")) .f.es <- effectsize::eta_squared
 
-    # Fisher's ANOVA
     if (isTRUE(paired)) {
+      # check if `afex` is installed
+      if (!requireNamespace("afex", quietly = TRUE)) stop("Package 'afex' needs to be installed.")
+
+      # Fisher's ANOVA
       mod <-
         afex::aov_ez(
           id = "rowid",
@@ -212,8 +209,8 @@ expr_oneway_anova <- function(data,
         )
     }
 
-    # Welch's ANOVA
     if (isFALSE(paired)) {
+      # Welch's ANOVA
       mod <-
         stats::oneway.test(
           formula = rlang::new_formula(y, x),
@@ -331,16 +328,16 @@ expr_oneway_anova <- function(data,
 
   # final returns
   if (type != "bayes") {
-    expression <-
-      expr_template(
+    stats_df %<>%
+      dplyr::mutate(expression = list(expr_template(
         no.parameters = no.parameters,
-        data = stats_df,
+        data = .,
         n = ifelse(isTRUE(paired), length(unique(data$rowid)), nrow(data)),
         paired = paired,
         k = k,
         k.df = k.df,
         k.df.error = k.df.error
-      )
+      )))
   }
 
   # ----------------------- Bayesian ---------------------------------------
@@ -364,16 +361,17 @@ expr_oneway_anova <- function(data,
     )
 
     # final return
-    expression <- stats_df <- bf_extractor(bf_object, conf.level, k = k, top.text = top.text, output = output)
+    stats_df <- bf_extractor(bf_object, conf.level, k = k, top.text = top.text)
   }
 
-  # return the output
-  switch(output,
-    "dataframe" = as_tibble(stats_df),
-    expression
-  )
+  as_tibble(stats_df)
 }
 
+#' @rdname oneway_anova
+#' @aliases oneway_anova
+#' @export
+
+expr_oneway_anova <- oneway_anova
 
 #' @noRd
 
