@@ -2,18 +2,18 @@
 # loops - correlation ---------------------------------------------------------
 
 test_that(
-  desc = "expr_corr_test works in loop",
+  desc = "corr_test works in loop",
   code = {
     col.name <- colnames(mtcars)
 
     set.seed(123)
     ls <-
       capture.output(for (i in 4:5) {
-        print(expr_corr_test(
+        print(corr_test(
           data = mtcars,
           x = disp,
           y = col.name[i],
-          type = "bayes", output = "dataframe"
+          type = "bayes"
         ))
       })
 
@@ -24,7 +24,7 @@ test_that(
 # loops - contingency tabs ---------------------------------------------------
 
 test_that(
-  desc = "expr_contingency_tab works in loop",
+  desc = "contingency_table works in loop",
   code = {
     df <- dplyr::select(mtcars, am, cyl, vs)
     col.name <- colnames(df)
@@ -32,10 +32,10 @@ test_that(
     set.seed(123)
     ls <-
       capture.output(for (i in 1:3) {
-        print(expr_contingency_tab(
+        print(contingency_table(
           data = mtcars,
           x = col.name[i],
-          type = "bayes", output = "dataframe"
+          type = "bayes"
         ))
       })
 
@@ -56,11 +56,11 @@ test_that(
     set.seed(123)
     ls1 <-
       capture.output(for (i in 2:length(col.name)) {
-        print(expr_t_twosample(
+        print(two_sample_test(
           data = mtcars,
           x = am,
           y = !!col.name[i],
-          type = "bayes", output = "dataframe"
+          type = "bayes"
         ))
       })
 
@@ -69,11 +69,11 @@ test_that(
     set.seed(123)
     ls2 <-
       capture.output(for (i in 2:length(col.name)) {
-        print(expr_t_onesample(
+        print(one_sample_test(
           data = mtcars,
           x = col.name[i],
           test.value = 3,
-          type = "bayes", output = "dataframe"
+          type = "bayes"
         ))
       })
 
@@ -95,11 +95,11 @@ test_that(
     set.seed(123)
     ls <-
       capture.output(for (i in 2:length(col.name)) {
-        print(expr_oneway_anova(
+        print(oneway_anova(
           data = mtcars,
           x = cyl,
           y = !!col.name[i],
-          type = "bayes", output = "dataframe"
+          type = "bayes"
         ))
       })
 
